#
# spec file for package SDL_bgi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           SDL_bgi
%define sover   suse9
%define lname	libSDL_bgi-%sover
Version:        3.0.2
Release:        1.3
Summary:        BGI-compatible 2D graphics C library with SDL backend
License:        GPL-2.0-or-later AND Zlib
Group:          Development/Libraries/X11
URL:            https://sdl-bgi.sourceforge.io/

#Freshcode:     http://freshcode.club/projects/sdl_bgi
Source:         https://downloads.sf.net/sdl-bgi/%name-%version.tar.gz
Source9:        %name-rpmlintrc
Patch1:         sdlbgi-cmake.diff
BuildRequires:  cmake
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(sdl2)

%description
SDL_bgi is largely compatible with BGI, the Borland Graphics
Interface that was a standard in PC graphics back in the DOS days.
SDL_bgi also provides extensions for RGB colors and mouse support.

%package -n %lname
Summary:        SDL Graphics Routines for Primitives and Other Support Functions
Group:          System/Libraries

%description -n %lname
SDL_bgi is a Borland Graphics Interface (BGI) emulation library for
SDL. It provides extensions for RGB colors and mouse support.

%package -n libSDL_bgi-devel
Summary:        Libraries, includes and more to develop SDL_bgi applications
Group:          Development/Libraries/X11
Requires:       %lname = %version-%release
Provides:       SDL_bgi-devel = %version-%release

%description -n libSDL_bgi-devel
SDL_bgi is a Borland Graphics Interface (BGI) emulation library for
SDL. It provides extensions for RGB colors and mouse support.

Unlike other BGI-compatible libraries, the purpose of SDL_bgi is not
full compatibility with BGI. Rather, it is meant to be an
introduction to SDL-based graphics: SDL and BGI commands can be mixed
together.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_INSTALL_DOCDIR:PATH="%_docdir/%name"
%cmake_build

%install
%cmake_install
# just a forwarder and conflicts with xbgi
rm -v "%buildroot/%_includedir/graphics.h"

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE
%_libdir/libSDL_bgi.so.*

%files -n libSDL_bgi-devel
%_docdir/%name/
%_includedir/*
%_libdir/libSDL_bgi.so
%_mandir/man3/*

%changelog
* Thu Sep  5 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.0.2
  * variable PALETTE_SIZE is accessible again
  * added clearmouseclick() function
  * initwindow() was extended
  * added a `bgicc` script
  * updated documentation and demo programs
* Wed Feb 28 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Align path for document installation between openSUSE versions.
  (Resolve failure to build the .spec because of a change in
  the default docdir for %%cmake in SUSE.)
* Thu Dec 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.0.0
  * fixed compatibility bugs in detectgraph(), gettextsettings(),
    getfillsettings(), drawpoly(), fillpoly(), setcolor(), lastkey(),
  * changed definition of `struct palettetype` (compatibility)
  * added colorname(), kdelay()
* Wed Jun  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.0
  * added getclick(), doubleclick(), extended mouseclick()
* Wed May  4 2022 Marcus Meissner <meissner@suse.com>
- updated source url to https
* Sun Feb 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.5.0
  * Modified functions putpixel(), setbkcolor(), setcolor(),
    setfillpattern(), setfillstyle(), setpalette(), and
    setalpha() to handle colours given as out of range numbers.
  * Simplified floodfill() function (implemented recursive version)
  * Improved setpalette() to change currently drawn pixels.
  * Added getrgbpalette(), setallrgbpalette(), and RGBPALETTE().
  * Implemented getwindowwidth() and getwindowheight() as macros
    for WinBGIm compatibility.
* Tue May  4 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.4
  * Fixed bug that affected floodfill() with fill patterns in
    rare cases
* Thu Mar  4 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.3
  * modified getscreensize() behaviour
  * added setwintitle()
* Wed Nov 11 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.2
  * Implemented native vector fonts, compatible with Borland .CHR
    fonts.
  * Implemented long-forgotten graphics error checks.
  * Added resetwinoptions(), getscreensize(), edelay(),
    getmaxheight(), getmaxwidth(), resizepalette(), added
    undocumented clearviewport() in setbkcolor().
  * Changed setwinoptions() to reset options for newly created
    windows.
  * Fixed graphresult() to provide actual error codes
  * Fixed compatibility in getpalette(), getpalettesize(),
    setallpalette(), setusercharsize().
  * Fixed setrgbpalette() to avoid out of range errors.
  * Improved fill patterns.
* Tue Aug 11 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.1
  * Implemented a 16-color palette that uses the same RGB values
    as Turbo C. This palette is used if the environment variable
    SDL_BGI_PALETTE is set to "BGI".
  * Extended the setpalette() function to modify the default 16
    colors too.
  * Added initpalette() to restore the original 16 colors.
  * Added more Hershey fonts: Cursive, Futural, Rowmant, and
    Timesr.
  * Fine tuning of Hershey font metrics; now they equal the
    metrics of corresponding .CHR fonts.
  * Preliminary .CHR font loading support.
* Thu Feb 20 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.0
  * Hershey font support as a replacement for the original
    Borland .chr fonts.
  * If the SDL_BGI_RES environment variable is set to "VGA",
    initgraph (DETECT, ...) forces VGA (640x480) resolution.
  * Added getlinebuffer() and putlinebuffer()
  * Changed 8x8 bitmap font using the one from the DosBox emulator.
- Drop sdlbgi-automake.diff, add sdlbgi-cmake.diff.
* Wed Jan 22 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.3.1
  * Added getbuffer(), putbuffer(), COLOR32(), and colorRGB
    (macro) for faster pixel manipulation; added showinfobox(),
    getleftclick(), getmiddleclick(), and getrightclick();
    documentation updates and improvements.
* Tue Aug 20 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.3.0
  * Added "auto mode": initgraph() performs automatic screen
    refresh when the environment variable SDL_BGI_RATE is set to
    "auto" or to the desired refresh rate (e.g. 60). This can be
    used as an alternative to "slow mode", and it provides a huge
    performance boost. The new function sdlbgiauto() is also
    available. BEWARE: automatic refresh may not work on some
    NVIDIA graphics cards.
  * Added compatibility with C++ programs
  * Added a showerrorbox() function
* Mon Nov 19 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.2.4
  * Added some graphics modes for better compatibility with
    old programs
* Wed Sep 19 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.2.3
  * fixed unspecified bug in setalpha()
* Tue Sep 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.2.2
  * The constants TMP_FG_COL, TMP_BG_COL, and TMP_FILL_COL
    were added.
* Wed Aug 15 2018 jengelh@inai.de
- Update to new upstream release 2.2.1
  * renamed getch() to bgi_getch() and added the macro getch()
    to avoid Mingw bug
  * delay() rewritten to take care of key presses
  * added ALPHA_VALUE()
* Thu Jul 26 2018 jengelh@inai.de
- Update to new upstream release 2.2.0
  * Added setwinoptions() for window title, position, and SDL
    flags.
  * Added support for multiple windows: extended initwindow(),
    added getcurrentwindow(), setcurrentwindow(), closewindow().
  * SDL_QUIT support in getch(), getevent(), kbhit(), xkbhit().
* Sun Jun 10 2018 jengelh@inai.de
- Update to new upstream release 2.1.2
  * Support for some Windows IDEs
* Fri Jan  5 2018 jengelh@inai.de
- Update to new upstream release 2.1.0
  * fixed a bug in getch()
  * added mouse wheel up/down events
* Tue Nov 15 2016 jengelh@inai.de
- Update to new upstream release 2.0.8
  * fixed unspecified bug in palette-manipulating functions
* Fri Nov 11 2016 jengelh@inai.de
- Update to new upstream release 2.0.7
  * fixed unspecified bug in event()
  * added the eventtype() funntion
* Fri Mar  4 2016 jengelh@inai.de
- Update to new upstream release 2.0.6
  * fixed bug in writeimagefile()
  * implemented clipping in readimagefile()
  * turtle graphics improvements
* Wed Dec 23 2015 jengelh@inai.de
- Update to new upstream release 2.0.5
  * fillpoly() correctly implemented
  * rewritten to use SDL_Surfaces only instead of
  bitmaps in main RAM
  * ellipse() and fillellipse() improved
  * xkbhit() added
* Mon Oct 12 2015 jengelh@inai.de
- Update to new upstream release 2.0.3
  * in "slow mode", screen refresh is also
  triggered by kbhit() and getch()
  * minimal dos.h and conio.h provided
  * kbhit() rewritten to avoid buffered keys
* Wed Jun  3 2015 jengelh@inai.de
- Update to new upstream release 2.0.2
  * fill patterns (not for floodfill())
  * setfillpattern() / getfillpattern () implemented
  * writeimagefile() added
  * documentation updates
* Tue May 12 2015 jengelh@inai.de
- Update to new upstream release 2.0.1
  * Support line patterns
  * Improvements to flood fills
* Thu May  7 2015 jengelh@inai.de
- Update to new upstream release 2.0.0
  * This uses SDL2 as backend
* Thu Dec 18 2014 jengelh@inai.de
- Initial package for build.opensuse.org (version 1.0.1).
  Add sdlbgi-automake.diff for a normal build that supports DESTDIR
  and uses pkgconfig.
